package vents.sim;

import java.io.BufferedInputStream;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.net.Socket;
import java.util.Random;

public class Experiment {
    public static final int MAP_TYPE_ZEROS = 0;
    public static final int MAP_TYPE_NEGATIVES = 1;
    public static final int MAP_TYPE_RANDOM1 = 2;
    public static final int MAP_TYPE_RANDOM2 = 3;
    
    public static final int DATA_TYPE_NEGATIVE = 0;
    public static final int DATA_TYPE_ZERO = 1;
    public static final int DATA_TYPE_BIG = 2;
    public static final int DATA_TYPE_SMALL1 = 3;
    public static final int DATA_TYPE_RANDOM1 = 4;
    public static final int DATA_TYPE_RANDOM2 = 5;
    private static Random random;
    
    public static void main(String argv[])
    {
        int mapType, dataType;
        if (argv.length != 2) {
            System.out.println("You must supply two parameters: map type and data type");
            System.out.println("map type is valid between 0 and 3");
            System.out.println("data type is valid between 0 and 5");
            return;
        }
        mapType = Integer.parseInt(argv[0]);
        dataType = Integer.parseInt(argv[1]);
        System.out.println("Using map type " + mapType + " and data type " + dataType);
        random = new Random();
        go(mapType, dataType);
    }
    
    public static void go(int mapType, int dataType) {
        try {
            System.out.println("Connecting to server");
            Socket socket = new Socket("ascendancypoint.com", 12345);
            DataOutputStream dout = new DataOutputStream(socket.getOutputStream());
            DataInputStream din = new DataInputStream(new BufferedInputStream(socket.getInputStream()));
            System.out.println("Sending data");
            sendState(dout, mapType, dataType);
            System.out.println("Waiting for response");
            int lines = din.readShort();
            System.out.println(lines + " lines from server");
            if(lines != 0)
            {
                for(int i = 0; i < lines; i++)
                {
                    String message = din.readUTF();
                    System.out.println(message);
                }
            } else
            {
                System.out.println("Invalid data");
            }
            socket.close();
        }catch(Throwable t) {
            System.out.println("Exception!");
            t.printStackTrace();
        }
    }
    
    public static void sendState(DataOutputStream out, int mapType, int dataType) throws IOException {
        byte mapValue = 0;
        int max = 0;
        for (int x = 0; x < 150; x++) {
            for (int y = 0; y < 150; y++) {
                switch(mapType) {
                case MAP_TYPE_ZEROS: mapValue = 0; break;
                case MAP_TYPE_NEGATIVES: mapValue = -1; break;
                case MAP_TYPE_RANDOM1: mapValue = (byte) random.nextInt(255); break; 
                case MAP_TYPE_RANDOM2: mapValue = (byte) random.nextInt(9); break; 
                }
                out.write((byte) mapValue);
            }

        }

        switch(dataType) {
        case DATA_TYPE_NEGATIVE:
            out.writeInt(-1);
            for (int i = 0; i < 10; i++) {
                out.writeInt(-1);
                out.writeShort(-1);
                out.writeShort(-1);
                out.writeShort(-1);
            }
            break;
        case DATA_TYPE_ZERO:
            out.writeInt(0);
            break;
        case DATA_TYPE_BIG:
            out.writeInt(Integer.MAX_VALUE);
            for (int i = 0; i < Integer.MAX_VALUE; i++) {
                out.writeInt(Integer.MAX_VALUE);
                out.writeShort(Short.MAX_VALUE);
                out.writeShort(Short.MAX_VALUE);
                out.writeShort(Short.MAX_VALUE);
            }
            break;
        case DATA_TYPE_SMALL1:
            out.writeInt(Integer.MIN_VALUE);
            for (int i = 0; i < 10; i++) {
                out.writeInt(Integer.MIN_VALUE);
                out.writeShort(Short.MIN_VALUE);
                out.writeShort(Short.MIN_VALUE);
                out.writeShort(Short.MIN_VALUE);
            }
            break;
        case DATA_TYPE_RANDOM1:
            max = random.nextInt(1000);
            System.out.println("Writing " + max + " random values.");
            out.writeInt(max);
            for (int i = 0; i < max; i++) {
                out.writeInt(random.nextInt());
                out.writeShort(random.nextInt(Short.MAX_VALUE));
                out.writeShort(random.nextInt(Short.MAX_VALUE));
                out.writeShort(random.nextInt(Short.MAX_VALUE));
            }
            break;
        case DATA_TYPE_RANDOM2:
            max = random.nextInt(50);
            System.out.println("Writing " + max + " random values.");
            out.writeInt(max);
            for (int i = 0; i < max; i++) {
                out.writeInt(random.nextInt());
                out.writeShort(random.nextInt(Short.MAX_VALUE));
                out.writeShort(random.nextInt(Short.MAX_VALUE));
                out.writeShort(random.nextInt(Short.MAX_VALUE));
            }
            break;
        }
    }
}
